package com.sf.system.deployment.controller;

import java.io.InputStream;
import java.net.URL;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.servlet.http.HttpServletResponse;

import com.sf.common.core.redis.RedisCache;
import com.sf.common.enums.RequestHeaderEnums;
import com.sf.common.utils.http.RequestUtils;
import com.sf.common.utils.openssl.AES256Util;
import com.sf.common.utils.uuid.UUID;
import com.sf.system.deployment.domain.rqs.ModuleListByCoreRequest;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.FileCopyUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.sf.common.annotation.Log;
import com.sf.common.core.controller.BaseController;
import com.sf.common.core.domain.AjaxResult;
import com.sf.common.enums.BusinessType;
import com.sf.system.deployment.domain.DeploymentModuleList;
import com.sf.system.deployment.service.IDeploymentModuleListService;
import com.sf.common.utils.poi.ExcelUtil;
import com.sf.common.core.page.TableDataInfo;

/**
 * H5模块包Controller
 *
 * @author ztzh
 * @date 2024-04-22
 */
@RestController
@RequestMapping("/deployment/module")
public class DeploymentModuleListController extends BaseController {
    @Autowired
    private IDeploymentModuleListService deploymentModuleListService;
    @Autowired
    private RedisCache redisCache;

    /**
     * 查询H5模块包列表
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeploymentModuleList deploymentModuleList) {
        deploymentModuleList.setAppCode(RequestUtils.getHeader(RequestHeaderEnums.APP_CODE.getCode()));
        startPage();
        List<DeploymentModuleList> list = deploymentModuleListService.selectDeploymentModuleListList(deploymentModuleList);
        return getDataTable(list);
    }

    /**
     * 查询H5模块包列表
     */
    @GetMapping("/qurey/list")
    public AjaxResult queryByCore(ModuleListByCoreRequest request) {
        DeploymentModuleList deploymentModuleList = new DeploymentModuleList();
        deploymentModuleList.setAppCode(RequestUtils.getHeader(RequestHeaderEnums.APP_CODE.getCode()));
        deploymentModuleList.setSysType(request.getSysType());
        List<DeploymentModuleList> list = deploymentModuleListService.selectDeploymentModuleListList(deploymentModuleList);
        return success(list);
    }

    /**
     * 查询模块包列表
     */
    @GetMapping("/qurey/file")
    public AjaxResult queryByCore(ModuleListByCoreRequest request, HttpServletResponse response) {
        DeploymentModuleList deploymentModuleList = new DeploymentModuleList();
        deploymentModuleList.setAppCode(RequestUtils.getHeader(RequestHeaderEnums.APP_CODE.getCode()));
        String authorization = RequestUtils.getHeader(RequestHeaderEnums.AUTHORIZATION.getCode());
        deploymentModuleList.setSysType(request.getSysType());
        deploymentModuleList.setModuleType(request.getModuleType());
        List<DeploymentModuleList> list = deploymentModuleListService.selectDeploymentModuleListList(deploymentModuleList);
        if (list.isEmpty() && null == list.get(0)) {
            throw new SecurityException("无可用模块包");
        }
        try {
            String password = UUID.randomUUID().toString().trim().replaceAll("-", "");
            //加密
            InputStream inputStream1 = AES256Util.encryptFile(password, new URL(list.get(0).getModuleUrl()).openStream());
            FileCopyUtils.copy(inputStream1, response.getOutputStream());
            redisCache.setCacheObject(authorization + request.getModuleType(), password, 3000, TimeUnit.MINUTES);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return success(null);
    }

    /**
     * 获取压缩包密码
     */
    @GetMapping("/qurey/ZipCore")
    public AjaxResult queryZipCore(ModuleListByCoreRequest request) {
        String authorization = RequestUtils.getHeader(RequestHeaderEnums.AUTHORIZATION.getCode());
        String cacheObject = redisCache.getCacheObject(authorization + request.getModuleType());
        return success(UUID.randomUUID().toString().trim().replaceAll("-", "") + cacheObject + UUID.randomUUID().toString().trim().replaceAll("-", ""))
        ;
    }


    /**
     * 导出H5模块包列表
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:export')")
    @Log(title = "H5模块包", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeploymentModuleList deploymentModuleList) {
        List<DeploymentModuleList> list = deploymentModuleListService.selectDeploymentModuleListList(deploymentModuleList);
        ExcelUtil<DeploymentModuleList> util = new ExcelUtil<DeploymentModuleList>(DeploymentModuleList.class);
        util.exportExcel(response, list, "H5模块包数据");
    }

    /**
     * 获取H5模块包详细信息
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(deploymentModuleListService.selectDeploymentModuleListById(id));
    }

    /**
     * 新增H5模块包
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:add')")
    @Log(title = "H5模块包", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DeploymentModuleList deploymentModuleList) {
        deploymentModuleList.setAppCode(RequestUtils.getHeader(RequestHeaderEnums.APP_CODE.getCode()));
        return toAjax(deploymentModuleListService.insertDeploymentModuleList(deploymentModuleList));
    }

    /**
     * 修改H5模块包
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:edit')")
    @Log(title = "H5模块包", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeploymentModuleList deploymentModuleList) {
        return toAjax(deploymentModuleListService.updateDeploymentModuleList(deploymentModuleList));
    }

    /**
     * 删除H5模块包
     */
    @PreAuthorize("@ss.hasPermi('deployment:module:remove')")
    @Log(title = "H5模块包", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(deploymentModuleListService.deleteDeploymentModuleListByIds(ids));
    }
}
