package com.sf.vertx.utils;

import java.util.List;
import java.util.regex.Pattern;

import com.sf.vertx.api.pojo.Node;
import com.sf.vertx.arithmetic.roundRobin.SacLoadBalancing;
import com.sf.vertx.arithmetic.roundRobin.WeightedRoundRobin;
import com.sf.vertx.handle.AppConfigHandler;

import io.vertx.core.http.HttpServerRequest;
import io.vertx.core.net.SocketAddress;
import lombok.extern.slf4j.Slf4j;

/***
 * 反向代理工具类
 * 
 * @author xy
 *
 */
@Slf4j
public class ProxyTool {
	
	public static SocketAddress resolveOriginAddress(HttpServerRequest request) {
		String appCode = request.getHeader(AppConfigHandler.getAppCodeHeaderKey());
		String apiCode = request.getHeader(AppConfigHandler.getApiCodeHeaderKey());
		log.info("uri:{}, header appCode:{},apiCode:{}", request.uri(), appCode, apiCode);
		SacLoadBalancing sacLoadBalancing = AppConfigHandler.getLoadBalancing(appCode + ":" + apiCode);
		// TODO 区分https、http
		Node node = sacLoadBalancing.selectNode();
		SocketAddress socketAddress = SocketAddress.inetSocketAddress(node.getPort(), node.getIp());
		log.info("sacLoadBalancing address:{},port:{}", socketAddress.host(), socketAddress.port());
		return socketAddress;
	}

	public static boolean regexMatch(String pattern, String target) {
		return Pattern.matches(pattern, target);
	}

	public static SacLoadBalancing roundRobin(List<Node> nodeList) {
		WeightedRoundRobin weightedRoundRobin = new WeightedRoundRobin();
		for (Node node : nodeList) {
			int weight = node.getWeight() != null ? node.getWeight() : 1;
			node.setWeight(weight);
			node.setCurrentWeight(weight);
			node.setEffectiveWeight(weight);
			weightedRoundRobin.totalWeight += node.getEffectiveWeight();
		}
		weightedRoundRobin.init(nodeList);
		return weightedRoundRobin;
	}
}
